@@ -5,14 +5,13 @@
 # grunseid.com
 # grunseid@gmail.com
 #
-# Copyright: LOLOLOL
-#
 # License: Build Amazing Things (Unlicense)
 
 __title__ = 'furl'
-__version__ = '0.2.2'
+__version__ = '0.3' # Keep synchronized with setup.py.
 __author__ = 'Arthur Grunseid'
+__contact__ = 'grunseid@gmail.com'
 __license__ = 'Unlicense'
-__copyright__ = 'LOLOLOL'
+__url__ = 'https://github.com/gruns/furl'
 
 from .furl import *
